==> haskell-uuid-1.3.16-87.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uuid
version:              1.3.16
visibility:           public
id:                   uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
key:                  uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  06b72abbdbb04782cb3422355f7e46d5
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uuid
hs-libraries:         HSuuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cryptohash-md5-0.11.101.0-J5UR8E8aYJ3Hd9sUYMKK9d
    cryptohash-sha1-0.11.101.0-BjsOb6FJgTCBp7n5ZEroI4
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    network-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm text-2.0.2 time-1.12.2
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.16-88-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uuid
version:              1.3.16
visibility:           public
id:                   uuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
key:                  uuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  76ae186cc3c4f199db9d9a9154d4c471
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uuid-1.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uuid
hs-libraries:         HSuuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cryptohash-md5-0.11.101.0-J74dyoGm3GrA8vovv3AXGQ
    cryptohash-sha1-0.11.101.0-I0vIPZWrlt0Gys06a7iUtx
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    network-info-0.2.1-1ELhTO025aF3xbpJiZvy4m
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj text-2.0.2 time-1.12.2
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
